---
sources:
    - name: meter_source
      meters:
          - "*"
      sinks:
          - meter_sink
sinks:
    - name: meter_sink
      publishers:
<% @pipeline_publishers.each do |publisher| -%>
          - <%= publisher %>
<% end -%>
